Date: 2022-10-01T06:39:22+00:00

Actual source code: slepcdsmod.F90
slepc-3.18.0 2022-10-01
Report Typos and Errors

      1: !
      2: !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      3: !  SLEPc - Scalable Library for Eigenvalue Problem Computations
      4: !  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
      5: !
      6: !  This file is part of SLEPc.
      7: !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
      8: !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      9: !
     10:         module slepcdsdef
     11:         use slepcfndef
     12:         use slepcrgdef
     13:         use slepcsys
     14: #include <../src/sys/classes/ds/f90-mod/slepcds.h>
     15:         end module

     17:         module slepcds
     18:         use slepcdsdef
     19:         use slepcfn
     20:         use slepcrg
     21: #include <../src/sys/classes/ds/f90-mod/slepcds.h90>
     22:         interface
     23: #include <../src/sys/classes/ds/f90-mod/ftn-auto-interfaces/slepcds.h90>
     24:         end interface
     25:         end module